@@ -29,8 +29,9 @@
 
 #include "rss_autodownloadrule.h"
 
+#include <algorithm>
+
 #include <QDebug>
-#include <QDir>
 #include <QHash>
 #include <QJsonArray>
 #include <QJsonObject>
@@ -61,27 +62,30 @@ namespace
         return TriStateBool::Undefined;
     }
 
-    QJsonValue triStateBoolToJsonValue(const TriStateBool &triStateBool)
+    QJsonValue triStateBoolToJsonValue(const TriStateBool triStateBool)
     {
-        switch (static_cast<int>(triStateBool)) {
+        switch (static_cast<signed char>(triStateBool))
+        {
         case 0:  return false;
         case 1:  return true;
-        default: return QJsonValue();
+        default: return {};
         }
     }
 
-    TriStateBool addPausedLegacyToTriStateBool(int val)
+    TriStateBool addPausedLegacyToTriStateBool(const int val)
     {
-        switch (val) {
+        switch (val)
+        {
         case 1:  return TriStateBool::True; // always
         case 2:  return TriStateBool::False; // never
         default: return TriStateBool::Undefined; // default
         }
     }
 
-    int triStateBoolToAddPausedLegacy(const TriStateBool &triStateBool)
+    int triStateBoolToAddPausedLegacy(const TriStateBool triStateBool)
     {
-        switch (static_cast<int>(triStateBool)) {
+        switch (static_cast<signed char>(triStateBool))
+        {
         case 0:  return 2; // never
         case 1:  return 1; // always
         default: return 0; // default
@@ -101,6 +105,7 @@ const QString Str_AssignedCategory(QStringLiteral("assignedCategory"));
 const QString Str_LastMatch(QStringLiteral("lastMatch"));
 const QString Str_IgnoreDays(QStringLiteral("ignoreDays"));
 const QString Str_AddPaused(QStringLiteral("addPaused"));
+const QString Str_CreateSubfolder(QStringLiteral("createSubfolder"));
 const QString Str_SmartFilter(QStringLiteral("smartFilter"));
 const QString Str_PreviouslyMatched(QStringLiteral("previouslyMatchedEpisodes"));
 
@@ -122,6 +127,7 @@ namespace RSS
         QString savePath;
         QString category;
         TriStateBool addPaused = TriStateBool::Undefined;
+        TriStateBool createSubfolder = TriStateBool::Undefined;
 
         bool smartFilter = false;
         QStringList previouslyMatchedEpisodes;
@@ -143,6 +149,7 @@ namespace RSS
                     && (savePath == other.savePath)
                     && (category == other.category)
                     && (addPaused == other.addPaused)
+                    && (createSubfolder == other.createSubfolder)
                     && (smartFilter == other.smartFilter);
         }
     };
@@ -157,17 +164,18 @@ QString computeEpisodeName(const QString &article)
 
     // See if we can extract an season/episode number or date from the title
     if (!match.hasMatch())
-        return QString();
+        return {};
 
     QStringList ret;
-    for (int i = 1; i <= match.lastCapturedIndex(); ++i) {
-        QString cap = match.captured(i);
+    for (int i = 1; i <= match.lastCapturedIndex(); ++i)
+    {
+        const QString cap = match.captured(i);
 
         if (cap.isEmpty())
             continue;
 
         bool isInt = false;
-        int x = cap.toInt(&isInt);
+        const int x = cap.toInt(&isInt);
 
         ret.append(isInt ? QString::number(x) : cap);
     }
@@ -187,7 +195,7 @@ AutoDownloadRule::AutoDownloadRule(const AutoDownloadRule &other)
 
 AutoDownloadRule::~AutoDownloadRule() {}
 
-QRegularExpression AutoDownloadRule::cachedRegex(const QString &expression, bool isRegex) const
+QRegularExpression AutoDownloadRule::cachedRegex(const QString &expression, const bool isRegex) const
 {
     // Use a cache of regexes so we don't have to continually recompile - big performance increase.
     // The cache is cleared whenever the regex/wildcard, must or must not contain fields or
@@ -195,8 +203,10 @@ QRegularExpression AutoDownloadRule::cachedRegex(const QString &expression, bool
     Q_ASSERT(!expression.isEmpty());
 
     QRegularExpression &regex = m_dataPtr->cachedRegexes[expression];
-    if (regex.pattern().isEmpty()) {
-        regex = QRegularExpression {
+    if (regex.pattern().isEmpty())
+    {
+        regex = QRegularExpression
+        {
                 (isRegex ? expression : Utils::String::wildcardToRegex(expression))
                 , QRegularExpression::CaseInsensitiveOption};
     }
@@ -208,20 +218,23 @@ bool AutoDownloadRule::matchesExpression(const QString &articleTitle, const QStr
 {
     const QRegularExpression whitespace {"\\s+"};
 
-    if (expression.isEmpty()) {
+    if (expression.isEmpty())
+    {
         // A regex of the form "expr|" will always match, so do the same for wildcards
         return true;
     }
 
-    if (m_dataPtr->useRegex) {
-        QRegularExpression reg(cachedRegex(expression));
+    if (m_dataPtr->useRegex)
+    {
+        const QRegularExpression reg(cachedRegex(expression));
         return reg.match(articleTitle).hasMatch();
     }
 
     // Only match if every wildcard token (separated by spaces) is present in the article name.
     // Order of wildcard tokens is unimportant (if order is important, they should have used *).
     const QStringList wildcards {expression.split(whitespace, QString::SplitBehavior::SkipEmptyParts)};
-    for (const QString &wildcard : wildcards) {
+    for (const QString &wildcard : wildcards)
+    {
         const QRegularExpression reg {cachedRegex(wildcard, false)};
         if (!reg.match(articleTitle).hasMatch())
             return false;
@@ -237,13 +250,11 @@ bool AutoDownloadRule::matchesMustContainExpression(const QString &articleTitle)
 
     // Each expression is either a regex, or a set of wildcards separated by whitespace.
     // Accept if any complete expression matches.
-    for (const QString &expression : asConst(m_dataPtr->mustContain)) {
+    return std::any_of(m_dataPtr->mustContain.cbegin(), m_dataPtr->mustContain.cend(), [this, &articleTitle](const QString &expression)
+    {
         // A regex of the form "expr|" will always match, so do the same for wildcards
-        if (matchesExpression(articleTitle, expression))
-            return true;
-    }
-
-    return false;
+        return matchesExpression(articleTitle, expression);
+    });
 }
 
 bool AutoDownloadRule::matchesMustNotContainExpression(const QString &articleTitle) const
@@ -253,13 +264,11 @@ bool AutoDownloadRule::matchesMustNotContainExpression(const QString &articleTit
 
     // Each expression is either a regex, or a set of wildcards separated by whitespace.
     // Reject if any complete expression matches.
-    for (const QString &expression : asConst(m_dataPtr->mustNotContain)) {
+    return std::none_of(m_dataPtr->mustNotContain.cbegin(), m_dataPtr->mustNotContain.cend(), [this, &articleTitle](const QString &expression)
+    {
         // A regex of the form "expr|" will always match, so do the same for wildcards
-        if (matchesExpression(articleTitle, expression))
-            return false;
-    }
-
-    return true;
+        return matchesExpression(articleTitle, expression);
+    });
 }
 
 bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString &articleTitle) const
@@ -279,7 +288,8 @@ bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString &articleTitl
     const QStringList episodes {matcher.captured(2).split(';')};
     const int seasonOurs {season.toInt()};
 
-    for (QString episode : episodes) {
+    for (QString episode : episodes)
+    {
         if (episode.isEmpty())
             continue;
 
@@ -287,7 +297,8 @@ bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString &articleTitl
         while ((episode.size() > 1) && episode.startsWith('0'))
             episode = episode.right(episode.size() - 1);
 
-        if (episode.indexOf('-') != -1) { // Range detected
+        if (episode.indexOf('-') != -1)
+        { // Range detected
             const QString partialPattern1 {"\\bs0?(\\d{1,4})[ -_\\.]?e(0?\\d{1,4})(?:\\D|\\b)"};
             const QString partialPattern2 {"\\b(\\d{1,4})x(0?\\d{1,4})(?:\\D|\\b)"};
 
@@ -295,21 +306,25 @@ bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString &articleTitl
             QRegularExpressionMatch matcher = cachedRegex(partialPattern1).match(articleTitle);
             bool matched = matcher.hasMatch();
 
-            if (!matched) {
+            if (!matched)
+            {
                 matcher = cachedRegex(partialPattern2).match(articleTitle);
                 matched = matcher.hasMatch();
             }
 
-            if (matched) {
+            if (matched)
+            {
                 const int seasonTheirs {matcher.captured(1).toInt()};
                 const int episodeTheirs {matcher.captured(2).toInt()};
 
-                if (episode.endsWith('-')) { // Infinite range
+                if (episode.endsWith('-'))
+                { // Infinite range
                     const int episodeOurs {episode.leftRef(episode.size() - 1).toInt()};
                     if (((seasonTheirs == seasonOurs) && (episodeTheirs >= episodeOurs)) || (seasonTheirs > seasonOurs))
                         return true;
                 }
-                else { // Normal range
+                else
+                { // Normal range
                     const QStringList range {episode.split('-')};
                     Q_ASSERT(range.size() == 2);
                     if (range.first().toInt() > range.last().toInt())
@@ -322,8 +337,9 @@ bool AutoDownloadRule::matchesEpisodeFilterExpression(const QString &articleTitl
                 }
             }
         }
-        else { // Single number
-            const QString expStr {QString("\\b(?:s0?%1[ -_\\.]?e0?%2|%1x0?%2)(?:\\D|\\b)").arg(season, episode)};
+        else
+        { // Single number
+            const QString expStr {QString::fromLatin1("\\b(?:s0?%1[ -_\\.]?e0?%2|%1x0?%2)(?:\\D|\\b)").arg(season, episode)};
             if (cachedRegex(expStr).match(articleTitle).hasMatch())
                 return true;
         }
@@ -343,7 +359,8 @@ bool AutoDownloadRule::matchesSmartEpisodeFilter(const QString &articleTitle) co
 
     // See if this episode has been downloaded before
     const bool previouslyMatched = m_dataPtr->previouslyMatchedEpisodes.contains(episodeStr);
-    if (previouslyMatched) {
+    if (previouslyMatched)
+    {
         if (!AutoDownloader::instance()->downloadRepacks())
             return false;
 
@@ -354,7 +371,7 @@ bool AutoDownloadRule::matchesSmartEpisodeFilter(const QString &articleTitle) co
         if (!isRepack && !isProper)
             return false;
 
-        const QString fullEpisodeStr = QString("%1%2%3").arg(episodeStr,
+        const QString fullEpisodeStr = QString::fromLatin1("%1%2%3").arg(episodeStr,
                                                              isRepack ? "-REPACK" : "",
                                                              isProper ? "-PROPER" : "");
         const bool previouslyMatchedFull = m_dataPtr->previouslyMatchedEpisodes.contains(fullEpisodeStr);
@@ -365,9 +382,10 @@ bool AutoDownloadRule::matchesSmartEpisodeFilter(const QString &articleTitle) co
 
         // If this is a REPACK and PROPER download, add the individual entries to the list
         // so we don't download those
-        if (isRepack && isProper) {
-            m_dataPtr->lastComputedEpisodes.append(QString("%1-REPACK").arg(episodeStr));
-            m_dataPtr->lastComputedEpisodes.append(QString("%1-PROPER").arg(episodeStr));
+        if (isRepack && isProper)
+        {
+            m_dataPtr->lastComputedEpisodes.append(episodeStr + QLatin1String("-REPACK"));
+            m_dataPtr->lastComputedEpisodes.append(episodeStr + QLatin1String("-PROPER"));
         }
     }
 
@@ -378,7 +396,8 @@ bool AutoDownloadRule::matchesSmartEpisodeFilter(const QString &articleTitle) co
 bool AutoDownloadRule::matches(const QVariantHash &articleData) const
 {
     const QDateTime articleDate {articleData[Article::KeyDate].toDateTime()};
-    if (ignoreDays() > 0) {
+    if (ignoreDays() > 0)
+    {
         if (lastMatch().isValid() && (articleDate < lastMatch().addDays(ignoreDays())))
             return false;
     }
@@ -404,7 +423,8 @@ bool AutoDownloadRule::accepts(const QVariantHash &articleData)
     setLastMatch(articleData[Article::KeyDate].toDateTime());
 
     // If there's a matched episode string, add that to the previously matched list
-    if (!m_dataPtr->lastComputedEpisodes.isEmpty()) {
+    if (!m_dataPtr->lastComputedEpisodes.isEmpty())
+    {
         m_dataPtr->previouslyMatchedEpisodes.append(m_dataPtr->lastComputedEpisodes);
         m_dataPtr->lastComputedEpisodes.clear();
     }
@@ -442,6 +462,7 @@ QJsonObject AutoDownloadRule::toJsonObject() const
         , {Str_LastMatch, lastMatch().toString(Qt::RFC2822Date)}
         , {Str_IgnoreDays, ignoreDays()}
         , {Str_AddPaused, triStateBoolToJsonValue(addPaused())}
+        , {Str_CreateSubfolder, triStateBoolToJsonValue(createSubfolder())}
         , {Str_SmartFilter, useSmartFilter()}
         , {Str_PreviouslyMatched, QJsonArray::fromStringList(previouslyMatchedEpisodes())}};
 }
@@ -458,6 +479,7 @@ AutoDownloadRule AutoDownloadRule::fromJsonObject(const QJsonObject &jsonObj, co
     rule.setSavePath(jsonObj.value(Str_SavePath).toString());
     rule.setCategory(jsonObj.value(Str_AssignedCategory).toString());
     rule.setAddPaused(jsonValueToTriStateBool(jsonObj.value(Str_AddPaused)));
+    rule.setCreateSubfolder(jsonValueToTriStateBool(jsonObj.value(Str_CreateSubfolder)));
     rule.setLastMatch(QDateTime::fromString(jsonObj.value(Str_LastMatch).toString(), Qt::RFC2822Date));
     rule.setIgnoreDays(jsonObj.value(Str_IgnoreDays).toInt());
     rule.setUseSmartFilter(jsonObj.value(Str_SmartFilter).toBool(false));
@@ -472,10 +494,12 @@ AutoDownloadRule AutoDownloadRule::fromJsonObject(const QJsonObject &jsonObj, co
 
     const QJsonValue previouslyMatchedVal = jsonObj.value(Str_PreviouslyMatched);
     QStringList previouslyMatched;
-    if (previouslyMatchedVal.isString()) {
+    if (previouslyMatchedVal.isString())
+    {
         previouslyMatched << previouslyMatchedVal.toString();
     }
-    else {
+    else
+    {
         for (const QJsonValue &val : asConst(previouslyMatchedVal.toArray()))
             previouslyMatched << val.toString();
     }
@@ -574,7 +598,7 @@ QString AutoDownloadRule::savePath() const
 
 void AutoDownloadRule::setSavePath(const QString &savePath)
 {
-    m_dataPtr->savePath = Utils::Fs::fromNativePath(savePath);
+    m_dataPtr->savePath = Utils::Fs::toUniformPath(savePath);
 }
 
 TriStateBool AutoDownloadRule::addPaused() const
@@ -582,11 +606,21 @@ TriStateBool AutoDownloadRule::addPaused() const
     return m_dataPtr->addPaused;
 }
 
-void AutoDownloadRule::setAddPaused(const TriStateBool &addPaused)
+void AutoDownloadRule::setAddPaused(const TriStateBool addPaused)
 {
     m_dataPtr->addPaused = addPaused;
 }
 
+TriStateBool AutoDownloadRule::createSubfolder() const
+{
+    return m_dataPtr->createSubfolder;
+}
+
+void AutoDownloadRule::setCreateSubfolder(const TriStateBool createSubfolder)
+{
+    m_dataPtr->createSubfolder = createSubfolder;
+}
+
 QString AutoDownloadRule::assignedCategory() const
 {
     return m_dataPtr->category;
@@ -602,7 +636,7 @@ bool AutoDownloadRule::isEnabled() const
     return m_dataPtr->enabled;
 }
 
-void AutoDownloadRule::setEnabled(bool enable)
+void AutoDownloadRule::setEnabled(const bool enable)
 {
     m_dataPtr->enabled = enable;
 }
@@ -617,7 +651,7 @@ void AutoDownloadRule::setLastMatch(const QDateTime &lastMatch)
     m_dataPtr->lastMatch = lastMatch;
 }
 
-void AutoDownloadRule::setIgnoreDays(int d)
+void AutoDownloadRule::setIgnoreDays(const int d)
 {
     m_dataPtr->ignoreDays = d;
 }
@@ -642,7 +676,7 @@ bool AutoDownloadRule::useSmartFilter() const
     return m_dataPtr->smartFilter;
 }
 
-void AutoDownloadRule::setUseSmartFilter(bool enabled)
+void AutoDownloadRule::setUseSmartFilter(const bool enabled)
 {
     m_dataPtr->smartFilter = enabled;
 }
@@ -652,7 +686,7 @@ bool AutoDownloadRule::useRegex() const
     return m_dataPtr->useRegex;
 }
 
-void AutoDownloadRule::setUseRegex(bool enabled)
+void AutoDownloadRule::setUseRegex(const bool enabled)
 {
     m_dataPtr->useRegex = enabled;
     m_dataPtr->cachedRegexes.clear();
