@@ -51,31 +51,31 @@
 #include "base/utils/fs.h"
 #include "base/utils/misc.h"
 #include "base/utils/string.h"
-#include "autoexpandabledialog.h"
+#include "gui/autoexpandabledialog.h"
+#include "gui/lineedit.h"
+#include "gui/raisedmessagebox.h"
+#include "gui/torrentcontentfiltermodel.h"
+#include "gui/torrentcontentmodel.h"
+#include "gui/uithememanager.h"
+#include "gui/utils.h"
 #include "downloadedpiecesbar.h"
-#include "lineedit.h"
 #include "peerlistwidget.h"
 #include "pieceavailabilitybar.h"
 #include "proplistdelegate.h"
 #include "proptabbar.h"
-#include "raisedmessagebox.h"
 #include "speedwidget.h"
-#include "torrentcontentfiltermodel.h"
-#include "torrentcontentmodel.h"
 #include "trackerlistwidget.h"
-#include "uithememanager.h"
-#include "utils.h"
-
 #include "ui_propertieswidget.h"
 
 #ifdef Q_OS_MACOS
-#include "macutilities.h"
+#include "gui/macutilities.h"
 #endif
 
 PropertiesWidget::PropertiesWidget(QWidget *parent)
     : QWidget(parent)
     , m_ui(new Ui::PropertiesWidget())
     , m_torrent(nullptr)
+    , m_handleWidth(-1)
 {
     m_ui->setupUi(this);
     setAutoFillBackground(true);
@@ -108,7 +108,7 @@ PropertiesWidget::PropertiesWidget(QWidget *parent)
     connect(m_ui->filesList, &QAbstractItemView::clicked
             , m_ui->filesList, qOverload<const QModelIndex &>(&QAbstractItemView::edit));
     connect(m_ui->filesList, &QWidget::customContextMenuRequested, this, &PropertiesWidget::displayFilesListMenu);
-    connect(m_ui->filesList, &QAbstractItemView::doubleClicked, this, &PropertiesWidget::openDoubleClickedFile);
+    connect(m_ui->filesList, &QAbstractItemView::doubleClicked, this, &PropertiesWidget::openItem);
     connect(m_ui->filesList->header(), &QHeaderView::sectionMoved, this, &PropertiesWidget::saveSettings);
     connect(m_ui->filesList->header(), &QHeaderView::sectionResized, this, &PropertiesWidget::saveSettings);
     connect(m_ui->filesList->header(), &QHeaderView::sortIndicatorChanged, this, &PropertiesWidget::saveSettings);
@@ -144,7 +144,7 @@ PropertiesWidget::PropertiesWidget(QWidget *parent)
     m_ui->vBoxLayoutPeerPage->addWidget(m_peerList);
     // Tab bar
     m_tabBar = new PropTabBar(nullptr);
-    m_tabBar->setContentsMargins(0, 5, 0, 0);
+    m_tabBar->setContentsMargins(0, 5, 0, 5);
     m_ui->verticalLayout->addLayout(m_tabBar);
     connect(m_tabBar, &PropTabBar::tabChanged, m_ui->stackedProperties, &QStackedWidget::setCurrentIndex);
     connect(m_tabBar, &PropTabBar::tabChanged, this, &PropertiesWidget::saveSettings);
@@ -192,15 +192,18 @@ void PropertiesWidget::showPiecesDownloaded(bool show)
         m_ui->lineBelowBars->setVisible(show);
 }
 
-void PropertiesWidget::setVisibility(bool visible)
+void PropertiesWidget::setVisibility(const bool visible)
 {
-    if (!visible && (m_state == VISIBLE)) {
+    if (!visible && (m_state == VISIBLE))
+    {
         const int tabBarHeight = m_tabBar->geometry().height(); // take height before hiding
         auto *hSplitter = static_cast<QSplitter *>(parentWidget());
         m_ui->stackedProperties->setVisible(false);
         m_slideSizes = hSplitter->sizes();
         hSplitter->handle(1)->setVisible(false);
         hSplitter->handle(1)->setDisabled(true);
+        m_handleWidth = hSplitter->handleWidth();
+        hSplitter->setHandleWidth(0);
         const QList<int> sizes {(hSplitter->geometry().height() - tabBarHeight), tabBarHeight};
         hSplitter->setSizes(sizes);
         setMaximumSize(maximumSize().width(), tabBarHeight);
@@ -208,9 +211,12 @@ void PropertiesWidget::setVisibility(bool visible)
         return;
     }
 
-    if (visible && (m_state == REDUCED)) {
+    if (visible && (m_state == REDUCED))
+    {
         m_ui->stackedProperties->setVisible(true);
         auto *hSplitter = static_cast<QSplitter *>(parentWidget());
+        if (m_handleWidth != -1)
+            hSplitter->setHandleWidth(m_handleWidth);
         hSplitter->handle(1)->setDisabled(false);
         hSplitter->handle(1)->setVisible(true);
         hSplitter->setSizes(m_slideSizes);
@@ -310,7 +316,8 @@ void PropertiesWidget::loadTorrentInfos(BitTorrent::TorrentHandle *const torrent
     // Hash
     m_ui->labelHashVal->setText(m_torrent->hash());
     m_propListModel->model()->clear();
-    if (m_torrent->hasMetadata()) {
+    if (m_torrent->hasMetadata())
+    {
         // Creation date
         m_ui->labelCreatedOnVal->setText(m_torrent->creationDate().toString(Qt::DefaultLocaleShortDate));
 
@@ -329,7 +336,8 @@ void PropertiesWidget::loadTorrentInfos(BitTorrent::TorrentHandle *const torrent
 
         // Expand single-item folders recursively
         QModelIndex currentIndex;
-        while (m_propListModel->rowCount(currentIndex) == 1) {
+        while (m_propListModel->rowCount(currentIndex) == 1)
+        {
             currentIndex = m_propListModel->index(0, 0, currentIndex);
             m_ui->filesList->setExpanded(currentIndex, true);
         }
@@ -346,7 +354,8 @@ void PropertiesWidget::readSettings()
     const Preferences *const pref = Preferences::instance();
     // Restore splitter sizes
     QStringList sizesStr = pref->getPropSplitterSizes().split(',');
-    if (sizesStr.size() == 2) {
+    if (sizesStr.size() == 2)
+    {
         m_slideSizes << sizesStr.first().toInt();
         m_slideSizes << sizesStr.last().toInt();
         auto *hSplitter = static_cast<QSplitter *>(parentWidget());
@@ -392,8 +401,10 @@ void PropertiesWidget::loadDynamicData()
     if (!m_torrent || (m_state != VISIBLE)) return;
 
     // Transfer infos
-    switch (m_ui->stackedProperties->currentIndex()) {
-    case PropTabBar::MainTab: {
+    switch (m_ui->stackedProperties->currentIndex())
+    {
+    case PropTabBar::MainTab:
+    {
             m_ui->labelWastedVal->setText(Utils::Misc::friendlyUnit(m_torrent->wastedSize()));
 
             m_ui->labelUpTotalVal->setText(tr("%1 (%2 this session)").arg(Utils::Misc::friendlyUnit(m_torrent->totalUpload())
@@ -452,16 +463,19 @@ void PropertiesWidget::loadDynamicData()
 
             m_ui->labelAddedOnVal->setText(m_torrent->addedTime().toString(Qt::DefaultLocaleShortDate));
 
-            if (m_torrent->hasMetadata()) {
+            if (m_torrent->hasMetadata())
+            {
                 m_ui->labelTotalPiecesVal->setText(tr("%1 x %2 (have %3)", "(torrent pieces) eg 152 x 4MB (have 25)").arg(m_torrent->piecesCount()).arg(Utils::Misc::friendlyUnit(m_torrent->pieceLength())).arg(m_torrent->piecesHave()));
 
-                if (!m_torrent->isSeed() && !m_torrent->isPaused() && !m_torrent->isQueued() && !m_torrent->isChecking()) {
+                if (!m_torrent->isSeed() && !m_torrent->isPaused() && !m_torrent->isQueued() && !m_torrent->isChecking())
+                {
                     // Pieces availability
                     showPiecesAvailability(true);
                     m_piecesAvailability->setAvailability(m_torrent->pieceAvailability());
                     m_ui->labelAverageAvailabilityVal->setText(Utils::String::fromDouble(m_torrent->distributedCopies(), 3));
                 }
-                else {
+                else
+                {
                     showPiecesAvailability(false);
                 }
 
@@ -470,7 +484,8 @@ void PropertiesWidget::loadDynamicData()
                 m_ui->labelProgressVal->setText(Utils::String::fromDouble(progress, 1) + '%');
                 m_downloadedPieces->setProgress(m_torrent->pieces(), m_torrent->downloadingPieces());
             }
-            else {
+            else
+            {
                 showPiecesAvailability(false);
             }
         }
@@ -485,7 +500,8 @@ void PropertiesWidget::loadDynamicData()
         break;
     case PropTabBar::FilesTab:
         // Files progress
-        if (m_torrent->hasMetadata()) {
+        if (m_torrent->hasMetadata())
+        {
             qDebug("Updating priorities in files tab");
             m_ui->filesList->setUpdatesEnabled(false);
             m_propListModel->model()->updateFilesProgress(m_torrent->filesProgress());
@@ -507,70 +523,52 @@ void PropertiesWidget::loadUrlSeeds()
     qDebug("Loading URL seeds");
     const QVector<QUrl> hcSeeds = m_torrent->urlSeeds();
     // Add url seeds
-    for (const QUrl &hcSeed : hcSeeds) {
+    for (const QUrl &hcSeed : hcSeeds)
+    {
         qDebug("Loading URL seed: %s", qUtf8Printable(hcSeed.toString()));
         new QListWidgetItem(hcSeed.toString(), m_ui->listWebSeeds);
     }
 }
 
-void PropertiesWidget::openDoubleClickedFile(const QModelIndex &index)
+QString PropertiesWidget::getFullPath(const QModelIndex &index) const
 {
-    if (!index.isValid() || !m_torrent || !m_torrent->hasMetadata()) return;
-
     if (m_propListModel->itemType(index) == TorrentContentModelItem::FileType)
-        openFile(index);
-    else
-        openFolder(index, false);
-}
-
-void PropertiesWidget::openFile(const QModelIndex &index)
-{
-    int i = m_propListModel->getFileIndex(index);
-    const QDir saveDir(m_torrent->savePath(true));
-    const QString filename = m_torrent->filePath(i);
-    const QString filePath = Utils::Fs::expandPath(saveDir.absoluteFilePath(filename));
-    qDebug("Trying to open file at %s", qUtf8Printable(filePath));
-    // Flush data
-    m_torrent->flushCache();
-    Utils::Gui::openPath(filePath);
-}
-
-void PropertiesWidget::openFolder(const QModelIndex &index, bool containingFolder)
-{
-    QString absolutePath;
-    // FOLDER
-    if (m_propListModel->itemType(index) == TorrentContentModelItem::FolderType) {
-        // Generate relative path to selected folder
-        QStringList pathItems;
-        pathItems << index.data().toString();
-        QModelIndex parent = m_propListModel->parent(index);
-        while (parent.isValid()) {
-            pathItems.prepend(parent.data().toString());
-            parent = m_propListModel->parent(parent);
-        }
-        if (pathItems.isEmpty())
-            return;
-        const QDir saveDir(m_torrent->savePath(true));
-        const QString relativePath = pathItems.join('/');
-        absolutePath = Utils::Fs::expandPath(saveDir.absoluteFilePath(relativePath));
-    }
-    else {
-        int i = m_propListModel->getFileIndex(index);
-        const QDir saveDir(m_torrent->savePath(true));
-        const QString relativePath = m_torrent->filePath(i);
-        absolutePath = Utils::Fs::expandPath(saveDir.absoluteFilePath(relativePath));
+    {
+        const int fileIdx = m_propListModel->getFileIndex(index);
+        const QString filename {m_torrent->filePath(fileIdx)};
+        const QDir saveDir {m_torrent->savePath(true)};
+        const QString fullPath {Utils::Fs::expandPath(saveDir.absoluteFilePath(filename))};
+        return fullPath;
     }
 
-    // Flush data
-    m_torrent->flushCache();
+    // folder type
+    const QModelIndex nameIndex {index.sibling(index.row(), TorrentContentModelItem::COL_NAME)};
+    QString folderPath {nameIndex.data().toString()};
+    for (QModelIndex modelIdx = m_propListModel->parent(nameIndex); modelIdx.isValid(); modelIdx = modelIdx.parent())
+        folderPath.prepend(modelIdx.data().toString() + '/');
+
+    const QDir saveDir {m_torrent->savePath(true)};
+    const QString fullPath {Utils::Fs::expandPath(saveDir.absoluteFilePath(folderPath))};
+    return fullPath;
+}
+
+void PropertiesWidget::openItem(const QModelIndex &index) const
+{
+    if (!index.isValid())
+        return;
+
+    m_torrent->flushCache();  // Flush data
+    Utils::Gui::openPath(getFullPath(index));
+}
+
+void PropertiesWidget::openParentFolder(const QModelIndex &index) const
+{
+    const QString path = getFullPath(index);
+    m_torrent->flushCache();  // Flush data
 #ifdef Q_OS_MACOS
-    Q_UNUSED(containingFolder);
-    MacUtils::openFiles(QSet<QString>{absolutePath});
+    MacUtils::openFiles({path});
 #else
-    if (containingFolder)
-        Utils::Gui::openFolderSelect(absolutePath);
-    else
-        Utils::Gui::openPath(absolutePath);
+    Utils::Gui::openFolderSelect(path);
 #endif
 }
 
@@ -584,14 +582,15 @@ void PropertiesWidget::displayFilesListMenu(const QPoint &)
     QMenu *menu = new QMenu(this);
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
-    if (selectedRows.size() == 1) {
+    if (selectedRows.size() == 1)
+    {
         const QModelIndex index = selectedRows[0];
 
         const QAction *actOpen = menu->addAction(UIThemeManager::instance()->getIcon("folder-documents"), tr("Open"));
-        connect(actOpen, &QAction::triggered, this, [this, index]() { openDoubleClickedFile(index); });
+        connect(actOpen, &QAction::triggered, this, [this, index]() { openItem(index); });
 
         const QAction *actOpenContainingFolder = menu->addAction(UIThemeManager::instance()->getIcon("inode-directory"), tr("Open Containing Folder"));
-        connect(actOpenContainingFolder, &QAction::triggered, this, [this, index]() { openFolder(index, true); });
+        connect(actOpenContainingFolder, &QAction::triggered, this, [this, index]() { openParentFolder(index); });
 
         const QAction *actRename = menu->addAction(UIThemeManager::instance()->getIcon("edit-rename"), tr("Rename..."));
         connect(actRename, &QAction::triggered, this, [this]() { m_ui->filesList->renameSelectedFile(m_torrent); });
@@ -599,12 +598,14 @@ void PropertiesWidget::displayFilesListMenu(const QPoint &)
         menu->addSeparator();
     }
 
-    if (!m_torrent->isSeed()) {
+    if (!m_torrent->isSeed())
+    {
         QMenu *subMenu = menu->addMenu(tr("Priority"));
 
         const auto applyPriorities = [this, selectedRows](const BitTorrent::DownloadPriority prio)
         {
-            for (const QModelIndex &index : selectedRows) {
+            for (const QModelIndex &index : selectedRows)
+            {
                 m_propListModel->setData(
                     m_propListModel->index(index.row(), PRIORITY, index.parent()), static_cast<int>(prio));
             }
@@ -662,7 +663,8 @@ void PropertiesWidget::displayWebSeedListMenu(const QPoint &)
     const QAction *actAdd = menu->addAction(UIThemeManager::instance()->getIcon("list-add"), tr("New Web seed"));
     connect(actAdd, &QAction::triggered, this, &PropertiesWidget::askWebSeed);
 
-    if (!rows.isEmpty()) {
+    if (!rows.isEmpty())
+    {
         const QAction *actDel = menu->addAction(UIThemeManager::instance()->getIcon("list-remove"), tr("Remove Web seed"));
         connect(actDel, &QAction::triggered, this, &PropertiesWidget::deleteSelectedUrlSeeds);
 
@@ -683,22 +685,26 @@ void PropertiesWidget::openSelectedFile()
     const QModelIndexList selectedIndexes = m_ui->filesList->selectionModel()->selectedRows(0);
     if (selectedIndexes.size() != 1)
         return;
-    openDoubleClickedFile(selectedIndexes.first());
+    openItem(selectedIndexes.first());
 }
 
 void PropertiesWidget::configure()
 {
     // Speed widget
-    if (Preferences::instance()->isSpeedWidgetEnabled()) {
-        if (!m_speedWidget || !qobject_cast<SpeedWidget *>(m_speedWidget)) {
+    if (Preferences::instance()->isSpeedWidgetEnabled())
+    {
+        if (!m_speedWidget || !qobject_cast<SpeedWidget *>(m_speedWidget))
+        {
             m_ui->speedLayout->removeWidget(m_speedWidget);
             delete m_speedWidget;
             m_speedWidget = new SpeedWidget {this};
             m_ui->speedLayout->addWidget(m_speedWidget);
         }
     }
-    else {
-        if (!m_speedWidget || !qobject_cast<QLabel *>(m_speedWidget)) {
+    else
+    {
+        if (!m_speedWidget || !qobject_cast<QLabel *>(m_speedWidget))
+        {
             m_ui->speedLayout->removeWidget(m_speedWidget);
             delete m_speedWidget;
             auto *label = new QLabel(tr("<center><b>Speed graphs are disabled</b><p>You may change this setting in Advanced Options </center>"), this);
@@ -718,7 +724,8 @@ void PropertiesWidget::askWebSeed()
                                                            QLatin1String("http://www."), &ok);
     if (!ok) return;
     qDebug("Adding %s web seed", qUtf8Printable(urlSeed));
-    if (!m_ui->listWebSeeds->findItems(urlSeed, Qt::MatchFixedString).empty()) {
+    if (!m_ui->listWebSeeds->findItems(urlSeed, Qt::MatchFixedString).empty())
+    {
         QMessageBox::warning(this, "qBittorrent",
                              tr("This URL seed is already in the list."),
                              QMessageBox::Ok);
@@ -771,7 +778,8 @@ void PropertiesWidget::editWebSeed()
                                                            oldSeed, &result);
     if (!result) return;
 
-    if (!m_ui->listWebSeeds->findItems(newSeed, Qt::MatchFixedString).empty()) {
+    if (!m_ui->listWebSeeds->findItems(newSeed, Qt::MatchFixedString).empty())
+    {
         QMessageBox::warning(this, tr("qBittorrent"),
                              tr("This URL seed is already in the list."),
                              QMessageBox::Ok);
@@ -797,11 +805,13 @@ void PropertiesWidget::filteredFilesChanged()
 void PropertiesWidget::filterText(const QString &filter)
 {
     m_propListModel->setFilterRegExp(QRegExp(filter, Qt::CaseInsensitive, QRegExp::WildcardUnix));
-    if (filter.isEmpty()) {
+    if (filter.isEmpty())
+    {
         m_ui->filesList->collapseAll();
         m_ui->filesList->expand(m_propListModel->index(0, 0));
     }
-    else {
+    else
+    {
         m_ui->filesList->expandAll();
     }
 }
