@@ -100,11 +100,20 @@ bool TransferListSortModel::lessThan_impl(const QModelIndex &left, const QModelI
         return lessThan_impl(left.sibling(left.row(), column), right.sibling(right.row(), column));
     };
 
+    const auto hashLessThan = [this, &left, &right]() -> bool
+    {
+        const TransferListModel *model = qobject_cast<TransferListModel *>(sourceModel());
+        const QString hashL = model->torrentHandle(left)->hash();
+        const QString hashR = model->torrentHandle(right)->hash();
+        return hashL < hashR;
+    };
+
     const int sortColumn = left.column();
     const QVariant leftValue = left.data(TransferListModel::UnderlyingDataRole);
     const QVariant rightValue = right.data(TransferListModel::UnderlyingDataRole);
 
-    switch (sortColumn) {
+    switch (sortColumn)
+    {
     case TransferListModel::TR_CATEGORY:
     case TransferListModel::TR_TAGS:
     case TransferListModel::TR_NAME:
@@ -124,26 +133,33 @@ bool TransferListSortModel::lessThan_impl(const QModelIndex &left, const QModelI
 
     case TransferListModel::TR_ADD_DATE:
     case TransferListModel::TR_SEED_DATE:
-    case TransferListModel::TR_SEEN_COMPLETE_DATE: {
+    case TransferListModel::TR_SEEN_COMPLETE_DATE:
+    {
             const QDateTime dateL = leftValue.toDateTime();
             const QDateTime dateR = rightValue.toDateTime();
 
-            if (dateL.isValid() && dateR.isValid()) {
+            if (dateL.isValid() && dateR.isValid())
+            {
                 if (dateL != dateR)
                     return dateL < dateR;
             }
-            else if (dateL.isValid()) {
+            else if (dateL.isValid())
+            {
                 return true;
             }
-            else if (dateR.isValid()) {
+            else if (dateR.isValid())
+            {
                 return false;
             }
-        }
-        break;
 
-    case TransferListModel::TR_QUEUE_POSITION: {
+            return hashLessThan();
+        }
+
+    case TransferListModel::TR_QUEUE_POSITION:
+    {
             // QVariant has comparators for all basic types
-            if ((leftValue > 0) || (rightValue > 0)) {
+            if ((leftValue > 0) || (rightValue > 0))
+            {
                 if ((leftValue > 0) && (rightValue > 0))
                     return leftValue < rightValue;
 
@@ -156,21 +172,26 @@ bool TransferListSortModel::lessThan_impl(const QModelIndex &left, const QModelI
             const QDateTime dateR = right.sibling(right.row(), TransferListModel::TR_SEED_DATE)
                     .data(TransferListModel::UnderlyingDataRole).toDateTime();
 
-            if (dateL.isValid() && dateR.isValid()) {
+            if (dateL.isValid() && dateR.isValid())
+            {
                 if (dateL != dateR)
                     return dateL < dateR;
             }
-            else if (dateL.isValid()) {
+            else if (dateL.isValid())
+            {
                 return false;
             }
-            else if (dateR.isValid()) {
+            else if (dateR.isValid())
+            {
                 return true;
             }
+
+            return hashLessThan();
         }
-        break;
 
     case TransferListModel::TR_SEEDS:
-    case TransferListModel::TR_PEERS: {
+    case TransferListModel::TR_PEERS:
+    {
             // QVariant has comparators for all basic types
             // Active peers/seeds take precedence over total peers/seeds.
             if (leftValue != rightValue)
@@ -184,7 +205,8 @@ bool TransferListSortModel::lessThan_impl(const QModelIndex &left, const QModelI
             return invokeLessThanForColumn(TransferListModel::TR_QUEUE_POSITION);
         }
 
-    case TransferListModel::TR_ETA: {
+    case TransferListModel::TR_ETA:
+    {
             // Sorting rules prioritized.
             // 1. Active torrents at the top
             // 2. Seeding torrents at the bottom
@@ -205,7 +227,8 @@ bool TransferListSortModel::lessThan_impl(const QModelIndex &left, const QModelI
                     .data(TransferListModel::UnderlyingDataRole).toInt();
             const bool isSeedingL = (queuePosL < 0);
             const bool isSeedingR = (queuePosR < 0);
-            if (isSeedingL != isSeedingR) {
+            if (isSeedingL != isSeedingR)
+            {
                 const bool isAscendingOrder = (sortOrder() == Qt::AscendingOrder);
                 if (isSeedingL)
                     return !isAscendingOrder;
@@ -217,7 +240,8 @@ bool TransferListSortModel::lessThan_impl(const QModelIndex &left, const QModelI
             const qlonglong etaR = rightValue.toLongLong();
             const bool isInvalidL = ((etaL < 0) || (etaL >= MAX_ETA));
             const bool isInvalidR = ((etaR < 0) || (etaR >= MAX_ETA));
-            if (isInvalidL && isInvalidR) {
+            if (isInvalidL && isInvalidR)
+            {
                 if (isSeedingL)  // Both seeding
                     return invokeLessThanForColumn(TransferListModel::TR_SEED_DATE);
 
@@ -237,19 +261,11 @@ bool TransferListSortModel::lessThan_impl(const QModelIndex &left, const QModelI
         if (rightValue < 0) return true;
 
         return (leftValue < rightValue);
-
-    default:
-        if (leftValue != rightValue)
-            return QSortFilterProxyModel::lessThan(left, right);
-
-        return invokeLessThanForColumn(TransferListModel::TR_QUEUE_POSITION);
     }
 
-    // Finally, sort by hash
-    const TransferListModel *model = qobject_cast<TransferListModel *>(sourceModel());
-    const QString hashL = model->torrentHandle(left)->hash();
-    const QString hashR = model->torrentHandle(right)->hash();
-    return hashL < hashR;
+    return (leftValue != rightValue)
+        ? QSortFilterProxyModel::lessThan(left, right)
+        : invokeLessThanForColumn(TransferListModel::TR_QUEUE_POSITION);
 }
 
 bool TransferListSortModel::filterAcceptsRow(const int sourceRow, const QModelIndex &sourceParent) const
