@@ -70,7 +70,8 @@ void AppController::versionAction()
 
 void AppController::buildInfoAction()
 {
-    const QJsonObject versions = {
+    const QJsonObject versions =
+    {
         {"qt", QT_VERSION_STR},
         {"libtorrent", Utils::Misc::libtorrentVersionString()},
         {"boost", Utils::Misc::boostVersionString()},
@@ -99,7 +100,7 @@ void AppController::preferencesAction()
 
     // Downloads
     // When adding a torrent
-    data["create_subfolder_enabled"] = session->isCreateTorrentSubfolder();
+    data["create_subfolder_enabled"] = session->isKeepTorrentTopLevelFolder();
     data["start_paused_enabled"] = session->isAddTorrentPaused();
     data["auto_delete_mode"] = static_cast<int>(TorrentFileGuard::autoDeleteMode());
     data["preallocate_all"] = session->isPreallocationEnabled();
@@ -117,7 +118,8 @@ void AppController::preferencesAction()
     // Automatically add torrents from
     const QVariantHash dirs = pref->getScanDirs();
     QJsonObject nativeDirs;
-    for (auto i = dirs.cbegin(); i != dirs.cend(); ++i) {
+    for (auto i = dirs.cbegin(); i != dirs.cend(); ++i)
+    {
         if (i.value().type() == QVariant::Int)
             nativeDirs.insert(Utils::Fs::toNativePath(i.key()), i.value().toInt());
         else
@@ -254,7 +256,7 @@ void AppController::preferencesAction()
     data["dyndns_domain"] = pref->getDynDomainName();
 
     // RSS settings
-    data["rss_refresh_interval"] = static_cast<double>(RSS::Session::instance()->refreshInterval());
+    data["rss_refresh_interval"] = RSS::Session::instance()->refreshInterval();
     data["rss_max_articles_per_feed"] = RSS::Session::instance()->maxArticlesPerFeed();
     data["rss_processing_enabled"] = RSS::Session::instance()->isProcessingEnabled();
     data["rss_auto_downloading_enabled"] = RSS::AutoDownloader::instance()->isProcessingEnabled();
@@ -268,7 +270,7 @@ void AppController::preferencesAction()
     // Current network interface address
     data["current_interface_address"] = BitTorrent::Session::instance()->networkInterfaceAddress();
     // Save resume data interval
-    data["save_resume_data_interval"] = static_cast<double>(session->saveResumeDataInterval());
+    data["save_resume_data_interval"] = session->saveResumeDataInterval();
     // Recheck completed torrents
     data["recheck_completed_torrents"] = pref->recheckTorrentsOnCompletion();
     // Resolve peer countries
@@ -277,6 +279,8 @@ void AppController::preferencesAction()
     // libtorrent preferences
     // Async IO threads
     data["async_io_threads"] = session->asyncIOThreads();
+    // Hashing threads
+    data["hashing_threads"] = session->hashingThreads();
     // File pool size
     data["file_pool_size"] = session->filePoolSize();
     // Checking memory usage
@@ -307,6 +311,10 @@ void AppController::preferencesAction()
     data["utp_tcp_mixed_mode"] = static_cast<int>(session->utpMixedMode());
     // Multiple connections per IP
     data["enable_multi_connections_from_same_ip"] = session->multiConnectionsPerIpEnabled();
+    // Validate HTTPS tracker certificate
+    data["validate_https_tracker_certificate"] = session->validateHTTPSTrackerCertificate();
+    // Disallow connection to peers on privileged ports
+    data["block_peers_on_privileged_ports"] = session->blockPeersOnPrivilegedPorts();
     // Embedded tracker
     data["enable_embedded_tracker"] = session->isTrackerEnabled();
     data["embedded_tracker_port"] = pref->getTrackerPort();
@@ -318,8 +326,12 @@ void AppController::preferencesAction()
     data["announce_to_all_trackers"] = session->announceToAllTrackers();
     data["announce_to_all_tiers"] = session->announceToAllTiers();
     data["announce_ip"] = session->announceIP();
-    // Stop tracker timeout
+    data["max_concurrent_http_announces"] = session->maxConcurrentHTTPAnnounces();
     data["stop_tracker_timeout"] = session->stopTrackerTimeout();
+    // Peer Turnover
+    data["peer_turnover"] = session->peerTurnover();
+    data["peer_turnover_cutoff"] = session->peerTurnoverCutoff();
+    data["peer_turnover_interval"] = session->peerTurnoverInterval();
 
     setResult(data);
 }
@@ -342,7 +354,7 @@ void AppController::setPreferencesAction()
     // Downloads
     // When adding a torrent
     if (hasKey("create_subfolder_enabled"))
-        session->setCreateTorrentSubfolder(it.value().toBool());
+        session->setKeepTorrentTopLevelFolder(it.value().toBool());
     if (hasKey("start_paused_enabled"))
         session->setAddTorrentPaused(it.value().toBool());
     if (hasKey("auto_delete_mode"))
@@ -373,21 +385,25 @@ void AppController::setPreferencesAction()
     if (hasKey("export_dir_fin"))
         session->setFinishedTorrentExportDirectory(it.value().toString());
     // Automatically add torrents from
-    if (hasKey("scan_dirs")) {
+    if (hasKey("scan_dirs"))
+    {
         const QVariantHash nativeDirs = it.value().toHash();
         QVariantHash oldScanDirs = pref->getScanDirs();
         QVariantHash scanDirs;
         ScanFoldersModel *model = ScanFoldersModel::instance();
-        for (auto i = nativeDirs.cbegin(); i != nativeDirs.cend(); ++i) {
+        for (auto i = nativeDirs.cbegin(); i != nativeDirs.cend(); ++i)
+        {
             QString folder = Utils::Fs::toUniformPath(i.key());
             int downloadType;
             QString downloadPath;
             ScanFoldersModel::PathStatus ec;
-            if (i.value().type() == QVariant::String) {
+            if (i.value().type() == QVariant::String)
+            {
                 downloadType = ScanFoldersModel::CUSTOM_LOCATION;
                 downloadPath = Utils::Fs::toUniformPath(i.value().toString());
             }
-            else {
+            else
+            {
                 downloadType = i.value().toInt();
                 downloadPath = (downloadType == ScanFoldersModel::DEFAULT_LOCATION) ? "Default folder" : "Watch folder";
             }
@@ -397,19 +413,23 @@ void AppController::setPreferencesAction()
             else
                 ec = model->updatePath(folder, static_cast<ScanFoldersModel::PathType>(downloadType), downloadPath);
 
-            if (ec == ScanFoldersModel::Ok) {
+            if (ec == ScanFoldersModel::Ok)
+            {
                 scanDirs.insert(folder, (downloadType == ScanFoldersModel::CUSTOM_LOCATION) ? QVariant(downloadPath) : QVariant(downloadType));
                 qDebug("New watched folder: %s to %s", qUtf8Printable(folder), qUtf8Printable(downloadPath));
             }
-            else {
+            else
+            {
                 qDebug("Watched folder %s failed with error %d", qUtf8Printable(folder), ec);
             }
         }
 
         // Update deleted folders
-        for (auto i = oldScanDirs.cbegin(); i != oldScanDirs.cend(); ++i) {
+        for (auto i = oldScanDirs.cbegin(); i != oldScanDirs.cend(); ++i)
+        {
             const QString &folder = i.key();
-            if (!scanDirs.contains(folder)) {
+            if (!scanDirs.contains(folder))
+            {
                 model->removePath(folder);
                 qDebug("Removed watched folder %s", qUtf8Printable(folder));
             }
@@ -545,13 +565,15 @@ void AppController::setPreferencesAction()
     if (hasKey("slow_torrent_inactive_timer"))
         session->setSlowTorrentsInactivityTimer(it.value().toInt());
     // Share Ratio Limiting
-    if (hasKey("max_ratio_enabled")) {
+    if (hasKey("max_ratio_enabled"))
+    {
         if (it.value().toBool())
             session->setGlobalMaxRatio(m["max_ratio"].toReal());
         else
             session->setGlobalMaxRatio(-1);
     }
-    if (hasKey("max_seeding_time_enabled")) {
+    if (hasKey("max_seeding_time_enabled"))
+    {
         if (it.value().toBool())
             session->setGlobalMaxSeedingMinutes(m["max_seeding_time"].toInt());
         else
@@ -560,19 +582,25 @@ void AppController::setPreferencesAction()
     if (hasKey("max_ratio_act"))
         session->setMaxRatioAction(static_cast<MaxRatioAction>(it.value().toInt()));
     // Add trackers
-    session->setAddTrackersEnabled(m["add_trackers_enabled"].toBool());
-    session->setAdditionalTrackers(m["add_trackers"].toString());
+    if (hasKey("add_trackers_enabled"))
+        session->setAddTrackersEnabled(it.value().toBool());
+    if (hasKey("add_trackers"))
+        session->setAdditionalTrackers(it.value().toString());
 
     // Web UI
     // Language
-    if (hasKey("locale")) {
+    if (hasKey("locale"))
+    {
         QString locale = it.value().toString();
-        if (pref->getLocale() != locale) {
+        if (pref->getLocale() != locale)
+        {
             auto *translator = new QTranslator;
-            if (translator->load(QLatin1String(":/lang/qbittorrent_") + locale)) {
+            if (translator->load(QLatin1String(":/lang/qbittorrent_") + locale))
+            {
                 qDebug("%s locale recognized, using translation.", qUtf8Printable(locale));
             }
-            else {
+            else
+            {
                 qDebug("%s locale unrecognized, using default (en).", qUtf8Printable(locale));
             }
             qApp->installTranslator(translator);
@@ -604,7 +632,8 @@ void AppController::setPreferencesAction()
         pref->setWebUiLocalAuthEnabled(!it.value().toBool());
     if (hasKey("bypass_auth_subnet_whitelist_enabled"))
         pref->setWebUiAuthSubnetWhitelistEnabled(it.value().toBool());
-    if (hasKey("bypass_auth_subnet_whitelist")) {
+    if (hasKey("bypass_auth_subnet_whitelist"))
+    {
         // recognize new lines and commas as delimiters
         pref->setWebUiAuthSubnetWhitelist(it.value().toString().split(QRegularExpression("\n|,"), QString::SkipEmptyParts));
     }
@@ -646,7 +675,7 @@ void AppController::setPreferencesAction()
         pref->setDynDomainName(it.value().toString());
 
     if (hasKey("rss_refresh_interval"))
-        RSS::Session::instance()->setRefreshInterval(it.value().toUInt());
+        RSS::Session::instance()->setRefreshInterval(it.value().toInt());
     if (hasKey("rss_max_articles_per_feed"))
         RSS::Session::instance()->setMaxArticlesPerFeed(it.value().toInt());
     if (hasKey("rss_processing_enabled"))
@@ -661,7 +690,8 @@ void AppController::setPreferencesAction()
     // Advanced settings
     // qBittorrent preferences
     // Current network interface
-    if (hasKey("current_network_interface")) {
+    if (hasKey("current_network_interface"))
+    {
         const QString ifaceValue {it.value().toString()};
 
         const QList<QNetworkInterface> ifaces = QNetworkInterface::allInterfaces();
@@ -675,7 +705,8 @@ void AppController::setPreferencesAction()
         session->setNetworkInterfaceName(ifaceName);
     }
     // Current network interface address
-    if (hasKey("current_interface_address")) {
+    if (hasKey("current_interface_address"))
+    {
         const QHostAddress ifaceAddress {it.value().toString().trimmed()};
         session->setNetworkInterfaceAddress(ifaceAddress.isNull() ? QString {} : ifaceAddress.toString());
     }
@@ -693,6 +724,9 @@ void AppController::setPreferencesAction()
     // Async IO threads
     if (hasKey("async_io_threads"))
         session->setAsyncIOThreads(it.value().toInt());
+    // Hashing threads
+    if (hasKey("hashing_threads"))
+        session->setHashingThreads(it.value().toInt());
     // File pool size
     if (hasKey("file_pool_size"))
         session->setFilePoolSize(it.value().toInt());
@@ -740,6 +774,12 @@ void AppController::setPreferencesAction()
     // Multiple connections per IP
     if (hasKey("enable_multi_connections_from_same_ip"))
         session->setMultiConnectionsPerIpEnabled(it.value().toBool());
+    // Validate HTTPS tracker certificate
+    if (hasKey("validate_https_tracker_certificate"))
+        session->setValidateHTTPSTrackerCertificate(it.value().toBool());
+    // Disallow connection to peers on privileged ports
+    if (hasKey("block_peers_on_privileged_ports"))
+        session->setBlockPeersOnPrivilegedPorts(it.value().toBool());
     // Embedded tracker
     if (hasKey("embedded_tracker_port"))
         pref->setTrackerPort(it.value().toInt());
@@ -756,13 +796,22 @@ void AppController::setPreferencesAction()
         session->setAnnounceToAllTrackers(it.value().toBool());
     if (hasKey("announce_to_all_tiers"))
         session->setAnnounceToAllTiers(it.value().toBool());
-    if (hasKey("announce_ip")) {
+    if (hasKey("announce_ip"))
+    {
         const QHostAddress announceAddr {it.value().toString().trimmed()};
         session->setAnnounceIP(announceAddr.isNull() ? QString {} : announceAddr.toString());
     }
-    // Stop tracker timeout
+    if (hasKey("max_concurrent_http_announces"))
+        session->setMaxConcurrentHTTPAnnounces(it.value().toInt());
     if (hasKey("stop_tracker_timeout"))
         session->setStopTrackerTimeout(it.value().toInt());
+    // Peer Turnover
+    if (hasKey("peer_turnover"))
+        session->setPeerTurnover(it.value().toInt());
+    if (hasKey("peer_turnover_cutoff"))
+        session->setPeerTurnoverCutoff(it.value().toInt());
+    if (hasKey("peer_turnover_interval"))
+        session->setPeerTurnoverInterval(it.value().toInt());
 
     // Save preferences
     pref->apply();
@@ -776,9 +825,12 @@ void AppController::defaultSavePathAction()
 void AppController::networkInterfaceListAction()
 {
     QJsonArray ifaceList;
-    for (const QNetworkInterface &iface : asConst(QNetworkInterface::allInterfaces())) {
-        if (!iface.addressEntries().isEmpty()) {
-            ifaceList.append(QJsonObject {
+    for (const QNetworkInterface &iface : asConst(QNetworkInterface::allInterfaces()))
+    {
+        if (!iface.addressEntries().isEmpty())
+        {
+            ifaceList.append(QJsonObject
+            {
                 {"name", iface.humanReadableName()},
                 {"value", iface.name()}
             });
@@ -803,11 +855,13 @@ void AppController::networkInterfaceAddressListAction()
             addressList.append(addr.toString());
     };
 
-    if (ifaceName.isEmpty()) {
+    if (ifaceName.isEmpty())
+    {
         for (const QHostAddress &addr : asConst(QNetworkInterface::allAddresses()))
             appendAddress(addr);
     }
-    else {
+    else
+    {
         const QNetworkInterface iface = QNetworkInterface::interfaceFromName(ifaceName);
         for (const QNetworkAddressEntry &entry : asConst(iface.addressEntries()))
             appendAddress(entry.ip());
