@@ -39,6 +39,7 @@
 #include "base/bittorrent/peerinfo.h"
 #include "base/bittorrent/session.h"
 #include "base/bittorrent/torrenthandle.h"
+#include "base/bittorrent/trackerentry.h"
 #include "base/global.h"
 #include "base/net/geoipmanager.h"
 #include "base/preferences.h"
@@ -163,20 +164,24 @@ namespace
         // initialize output variable
         syncData.clear();
 
-        for (auto i = data.cbegin(); i != data.cend(); ++i) {
+        for (auto i = data.cbegin(); i != data.cend(); ++i)
+        {
             const QString &key = i.key();
             const QVariant &value = i.value();
             QVariantList removedItems;
 
-            switch (static_cast<QMetaType::Type>(value.type())) {
-            case QMetaType::QVariantMap: {
+            switch (static_cast<QMetaType::Type>(value.type()))
+            {
+            case QMetaType::QVariantMap:
+            {
                     QVariantMap map;
                     processMap(prevData[key].toMap(), value.toMap(), map);
                     if (!map.isEmpty())
                         syncData[key] = map;
                 }
                 break;
-            case QMetaType::QVariantHash: {
+            case QMetaType::QVariantHash:
+            {
                     QVariantMap map;
                     processHash(prevData[key].toHash(), value.toHash(), map, removedItems);
                     if (!map.isEmpty())
@@ -185,7 +190,8 @@ namespace
                         syncData[key + KEY_SUFFIX_REMOVED] = removedItems;
                 }
                 break;
-            case QMetaType::QVariantList: {
+            case QMetaType::QVariantList:
+            {
                     QVariantList list;
                     processList(prevData[key].toList(), value.toList(), list, removedItems);
                     if (!list.isEmpty())
@@ -224,27 +230,55 @@ namespace
         syncData.clear();
         removedItems.clear();
 
-        if (prevData.isEmpty()) {
+        if (prevData.isEmpty())
+        {
             // If list was empty before, then difference is a whole new list.
             for (auto i = data.cbegin(); i != data.cend(); ++i)
                 syncData[i.key()] = i.value();
         }
-        else {
-            for (auto i = data.cbegin(); i != data.cend(); ++i) {
-                switch (i.value().type()) {
+        else
+        {
+            for (auto i = data.cbegin(); i != data.cend(); ++i)
+            {
+                switch (i.value().type())
+                {
                 case QVariant::Map:
-                    if (!prevData.contains(i.key())) {
+                    if (!prevData.contains(i.key()))
+                    {
                         // new list item found - append it to syncData
                         syncData[i.key()] = i.value();
                     }
-                    else {
+                    else
+                    {
                         QVariantMap map;
                         processMap(prevData[i.key()].toMap(), i.value().toMap(), map);
                         // existing list item found - remove it from prevData
                         prevData.remove(i.key());
                         if (!map.isEmpty())
+                        {
                             // changed list item found - append its changes to syncData
                             syncData[i.key()] = map;
+                        }
+                    }
+                    break;
+                case QVariant::StringList:
+                    if (!prevData.contains(i.key()))
+                    {
+                        // new list item found - append it to syncData
+                        syncData[i.key()] = i.value();
+                    }
+                    else
+                    {
+                        QVariantList list;
+                        QVariantList removedList;
+                        processList(prevData[i.key()].toList(), i.value().toList(), list, removedList);
+                        // existing list item found - remove it from prevData
+                        prevData.remove(i.key());
+                        if (!list.isEmpty() || !removedList.isEmpty())
+                        {
+                            // changed list item found - append entire list to syncData
+                            syncData[i.key()] = i.value();
+                        }
                     }
                     break;
                 default:
@@ -252,7 +286,8 @@ namespace
                 }
             }
 
-            if (!prevData.isEmpty()) {
+            if (!prevData.isEmpty())
+            {
                 // prevData contains only items that are missing now -
                 // put them in removedItems
                 for (auto i = prevData.cbegin(); i != prevData.cend(); ++i)
@@ -268,12 +303,15 @@ namespace
         syncData.clear();
         removedItems.clear();
 
-        if (prevData.isEmpty()) {
+        if (prevData.isEmpty())
+        {
             // If list was empty before, then difference is a whole new list.
             syncData = data;
         }
-        else {
-            for (const QVariant &item : data) {
+        else
+        {
+            for (const QVariant &item : data)
+            {
                 if (!prevData.contains(item))
                     // new list item found - append it to syncData
                     syncData.append(item);
@@ -294,7 +332,8 @@ namespace
         QVariantMap syncData;
         bool fullUpdate = true;
         int lastResponseId = 0;
-        if (acceptedResponseId > 0) {
+        if (acceptedResponseId > 0)
+        {
             lastResponseId = lastData[KEY_RESPONSE_ID].toInt();
 
             if (lastResponseId == acceptedResponseId)
@@ -302,13 +341,15 @@ namespace
 
             int lastAcceptedResponseId = lastAcceptedData[KEY_RESPONSE_ID].toInt();
 
-            if (lastAcceptedResponseId == acceptedResponseId) {
+            if (lastAcceptedResponseId == acceptedResponseId)
+            {
                 processMap(lastAcceptedData, data, syncData);
                 fullUpdate = false;
             }
         }
 
-        if (fullUpdate) {
+        if (fullUpdate)
+        {
             lastAcceptedData.clear();
             syncData = data;
             syncData[KEY_FULL_UPDATE] = true;
@@ -354,6 +395,8 @@ SyncController::~SyncController()
 //  - "torrents_removed": a list of hashes of removed torrents
 //  - "categories": map of categories info
 //  - "categories_removed": list of removed categories
+//  - "trackers": dictionary contains information about trackers
+//  - "trackers_removed": a list of removed trackers
 //  - "server_state": map contains information about the state of the server
 // The keys of the 'torrents' dictionary are hashes of torrents.
 // Each value of the 'torrents' dictionary contains map. The map can contain following keys:
@@ -414,7 +457,9 @@ void SyncController::maindataAction()
     QVariantMap lastAcceptedResponse = sessionManager()->session()->getData(QLatin1String("syncMainDataLastAcceptedResponse")).toMap();
 
     QVariantHash torrents;
-    for (const BitTorrent::TorrentHandle *torrent : asConst(session->torrents())) {
+    QHash<QString, QStringList> trackers;
+    for (const BitTorrent::TorrentHandle *torrent : asConst(session->torrents()))
+    {
         const BitTorrent::InfoHash torrentHash = torrent->hash();
 
         QVariantMap map = serialize(*torrent);
@@ -423,15 +468,18 @@ void SyncController::maindataAction()
         // Calculated last activity time can differ from actual value by up to 10 seconds (this is a libtorrent issue).
         // So we don't need unnecessary updates of last activity time in response.
         const auto iterTorrents = lastResponse.find("torrents");
-        if (iterTorrents != lastResponse.end()) {
+        if (iterTorrents != lastResponse.end())
+        {
             const QVariantHash lastResponseTorrents = iterTorrents->toHash();
             const auto iterHash = lastResponseTorrents.find(torrentHash);
 
-            if (iterHash != lastResponseTorrents.end()) {
+            if (iterHash != lastResponseTorrents.end())
+            {
                 const QVariantMap torrentData = iterHash->toMap();
                 const auto iterLastActivity = torrentData.find(KEY_TORRENT_LAST_ACTIVITY_TIME);
 
-                if (iterLastActivity != torrentData.end()) {
+                if (iterLastActivity != torrentData.end())
+                {
                     const int lastValue = iterLastActivity->toInt();
                     if (qAbs(lastValue - map[KEY_TORRENT_LAST_ACTIVITY_TIME].toInt()) < 15)
                         map[KEY_TORRENT_LAST_ACTIVITY_TIME] = lastValue;
@@ -439,15 +487,20 @@ void SyncController::maindataAction()
             }
         }
 
+        for (const BitTorrent::TrackerEntry &tracker : asConst(torrent->trackers()))
+            trackers[tracker.url()] << torrentHash;
+
         torrents[torrentHash] = map;
     }
     data["torrents"] = torrents;
 
     QVariantHash categories;
     const QStringMap categoriesList = session->categories();
-    for (auto it = categoriesList.cbegin(); it != categoriesList.cend(); ++it) {
+    for (auto it = categoriesList.cbegin(); it != categoriesList.cend(); ++it)
+    {
         const QString &key = it.key();
-        categories[key] = QVariantMap {
+        categories[key] = QVariantMap
+        {
             {"name", key},
             {"savePath", it.value()}
         };
@@ -459,6 +512,13 @@ void SyncController::maindataAction()
         tags << tag;
     data["tags"] = tags;
 
+    QVariantHash trackersHash;
+    for (auto i = trackers.constBegin(); i != trackers.constEnd(); ++i)
+    {
+        trackersHash[i.key()] = i.value();
+    }
+    data["trackers"] = trackersHash;
+
     QVariantMap serverState = getTransferInfo();
     serverState[KEY_TRANSFER_FREESPACEONDISK] = getFreeDiskSpace();
     serverState[KEY_SYNC_MAINDATA_QUEUEING] = session->isQueueingSystemEnabled();
@@ -491,18 +551,16 @@ void SyncController::torrentPeersAction()
 
     const QVector<BitTorrent::PeerInfo> peersList = torrent->peers();
 
-#ifndef DISABLE_COUNTRIES_RESOLUTION
     bool resolvePeerCountries = Preferences::instance()->resolvePeerCountries();
-#else
-    bool resolvePeerCountries = false;
-#endif
 
     data[KEY_SYNC_TORRENT_PEERS_SHOW_FLAGS] = resolvePeerCountries;
 
-    for (const BitTorrent::PeerInfo &pi : peersList) {
+    for (const BitTorrent::PeerInfo &pi : peersList)
+    {
         if (pi.address().ip.isNull()) continue;
 
-        QVariantMap peer = {
+        QVariantMap peer =
+        {
             {KEY_PEER_IP, pi.address().ip.toString()},
             {KEY_PEER_PORT, pi.address().port},
             {KEY_PEER_CLIENT, pi.client()},
@@ -518,14 +576,13 @@ void SyncController::torrentPeersAction()
             {KEY_PEER_FILES, torrent->info().filesForPiece(pi.downloadingPieceIndex()).join('\n')}
         };
 
-#ifndef DISABLE_COUNTRIES_RESOLUTION
-        if (resolvePeerCountries) {
+        if (resolvePeerCountries)
+        {
             peer[KEY_PEER_COUNTRY_CODE] = pi.country().toLower();
             peer[KEY_PEER_COUNTRY] = Net::GeoIPManager::CountryName(pi.country());
         }
-#endif
 
-        peers[pi.address().ip.toString() + ':' + QString::number(pi.address().port)] = peer;
+        peers[pi.address().toString()] = peer;
     }
     data["peers"] = peers;
 
@@ -538,7 +595,8 @@ void SyncController::torrentPeersAction()
 
 qint64 SyncController::getFreeDiskSpace()
 {
-    if (m_freeDiskSpaceElapsedTimer.hasExpired(FREEDISKSPACE_CHECK_TIMEOUT)) {
+    if (m_freeDiskSpaceElapsedTimer.hasExpired(FREEDISKSPACE_CHECK_TIMEOUT))
+    {
         invokeChecker();
         m_freeDiskSpaceElapsedTimer.restart();
     }
